==> jc-1.4.0.tar.gz: soot/dava/internal/SET/SETTryNode.h <==
// public class soot.dava.internal.SET.SETTryNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4d3d060182af30b5 soot_dava_internal_SET_SETNode
// @dep_class a2f0654b969241b9 soot_dava_internal_SET_SETTryNode

// header file dependencies
// @dep_header soot_dava_internal_SET_SETNode

#include "soot/dava/internal/SET/SETNode.h"

#ifndef _JC_soot_dava_internal_SET_SETTryNode_H_
#define _JC_soot_dava_internal_SET_SETTryNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_soot_dava_DavaBody$object;
struct _jc_soot_dava_internal_AST_ASTNode$object;
struct _jc_soot_dava_internal_SET_SETNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object;
struct _jc_soot_dava_toolkits_base_finders_ExceptionNode$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_internal_SET_SETTryNode$sub_refs	_jc_soot_dava_internal_SET_SETTryNode$sub_refs;
typedef struct _jc_soot_dava_internal_SET_SETTryNode$sub_nonrefs	_jc_soot_dava_internal_SET_SETTryNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETTryNode$refs	_jc_soot_dava_internal_SET_SETTryNode$refs;
typedef struct _jc_soot_dava_internal_SET_SETTryNode$nonrefs	_jc_soot_dava_internal_SET_SETTryNode$nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETTryNode$object	_jc_soot_dava_internal_SET_SETTryNode$object;

typedef const struct _jc_soot_dava_internal_SET_SETTryNode$vmethods	_jc_soot_dava_internal_SET_SETTryNode$vmethods;
typedef const struct _jc_soot_dava_internal_SET_SETTryNode$vtable	_jc_soot_dava_internal_SET_SETTryNode$vtable;
typedef const struct _jc_soot_dava_internal_SET_SETTryNode$vtype	_jc_soot_dava_internal_SET_SETTryNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_SET_SETTryNode$method$_init$a4d6c374d8192ed2(_jc_env *, struct _jc_soot_dava_internal_SET_SETTryNode$object *, struct _jc_soot_util_IterableSet$object *, struct _jc_soot_dava_toolkits_base_finders_ExceptionNode$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_DavaBody$object *);

// Virtual methods
extern struct _jc_soot_dava_internal_AST_ASTNode$object *_jc_soot_dava_internal_SET_SETTryNode$method$emit__5fAST$9abd6bb299fe14c5(_jc_env *, struct _jc_soot_dava_internal_SET_SETTryNode$object *);
extern struct _jc_soot_dava_internal_asg_AugmentedStmt$object *_jc_soot_dava_internal_SET_SETTryNode$method$get__5fEntryStmt$d3b7a698292e24c9(_jc_env *, struct _jc_soot_dava_internal_SET_SETTryNode$object *);
extern struct _jc_soot_util_IterableSet$object *_jc_soot_dava_internal_SET_SETTryNode$method$get__5fNaturalExits$93615053d2db173e(_jc_env *, struct _jc_soot_dava_internal_SET_SETTryNode$object *);
extern jboolean _jc_soot_dava_internal_SET_SETTryNode$method$resolve$e7ca43c456f15a88(_jc_env *, struct _jc_soot_dava_internal_SET_SETTryNode$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_SET_SETTryNode$method_info$emit__5fAST$9abd6bb299fe14c5;
extern _jc_method _jc_soot_dava_internal_SET_SETTryNode$method_info$get__5fEntryStmt$d3b7a698292e24c9;
extern _jc_method _jc_soot_dava_internal_SET_SETTryNode$method_info$get__5fNaturalExits$93615053d2db173e;
extern _jc_method _jc_soot_dava_internal_SET_SETTryNode$method_info$resolve$e7ca43c456f15a88;

// Virtual methods structure
struct _jc_soot_dava_internal_SET_SETTryNode$vmethods {
	struct _jc_soot_dava_internal_AST_ASTNode$object	*(*emit__5fAST$9abd6bb299fe14c5)(_jc_env *, struct _jc_soot_dava_internal_SET_SETTryNode$object *);
	struct _jc_soot_dava_internal_asg_AugmentedStmt$object	*(*get__5fEntryStmt$d3b7a698292e24c9)(_jc_env *, struct _jc_soot_dava_internal_SET_SETTryNode$object *);
	struct _jc_soot_util_IterableSet$object	*(*get__5fNaturalExits$93615053d2db173e)(_jc_env *, struct _jc_soot_dava_internal_SET_SETTryNode$object *);
	jboolean	(*resolve$e7ca43c456f15a88)(_jc_env *, struct _jc_soot_dava_internal_SET_SETTryNode$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
};

// Vtable
struct _jc_soot_dava_internal_SET_SETTryNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_internal_SET_SETNode$vmethods	soot_dava_internal_SET_SETNode;
	_jc_soot_dava_internal_SET_SETTryNode$vmethods	soot_dava_internal_SET_SETTryNode;
};

// Vtype
struct _jc_soot_dava_internal_SET_SETTryNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_SET_SETTryNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETTryNode$sub_refs {
	struct _jc_soot_dava_toolkits_base_finders_ExceptionNode$object	*en;
	struct _jc_soot_dava_DavaBody$object	*davaBody;
	struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object	*asg;
	struct _jc_java_util_HashMap$object	*cb2clone;
	struct _jc_soot_dava_internal_asg_AugmentedStmt$object	*entgryStmt;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETTryNode$refs {
    _jc_soot_dava_internal_SET_SETTryNode$sub_refs	soot_dava_internal_SET_SETTryNode;
    _jc_soot_dava_internal_SET_SETNode$sub_refs	soot_dava_internal_SET_SETNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETTryNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETTryNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_internal_SET_SETNode$sub_nonrefs	soot_dava_internal_SET_SETNode;
    _jc_soot_dava_internal_SET_SETTryNode$sub_nonrefs	soot_dava_internal_SET_SETTryNode;
};

// Object instance structure
struct _jc_soot_dava_internal_SET_SETTryNode$object {
	_jc_soot_dava_internal_SET_SETTryNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_SET_SETTryNode$vtype	*vtype;
	_jc_soot_dava_internal_SET_SETTryNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_SET_SETTryNode$vtype _jc_soot_dava_internal_SET_SETTryNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_SET_SETTryNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_SET_SETTryNode$class_object;

#endif	/* _JC_soot_dava_internal_SET_SETTryNode_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/SET/SETTryNode.h <==
// public class soot.dava.internal.SET.SETTryNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4d3d060182af30b5 soot_dava_internal_SET_SETNode
// @dep_class a2f0654b969241b9 soot_dava_internal_SET_SETTryNode

// header file dependencies
// @dep_header soot_dava_internal_SET_SETNode

#include "soot/dava/internal/SET/SETNode.h"

#ifndef _JC_soot_dava_internal_SET_SETTryNode_H_
#define _JC_soot_dava_internal_SET_SETTryNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_soot_dava_DavaBody$object;
struct _jc_soot_dava_internal_AST_ASTNode$object;
struct _jc_soot_dava_internal_SET_SETNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object;
struct _jc_soot_dava_toolkits_base_finders_ExceptionNode$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_internal_SET_SETTryNode$sub_refs	_jc_soot_dava_internal_SET_SETTryNode$sub_refs;
typedef struct _jc_soot_dava_internal_SET_SETTryNode$sub_nonrefs	_jc_soot_dava_internal_SET_SETTryNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETTryNode$refs	_jc_soot_dava_internal_SET_SETTryNode$refs;
typedef struct _jc_soot_dava_internal_SET_SETTryNode$nonrefs	_jc_soot_dava_internal_SET_SETTryNode$nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETTryNode$object	_jc_soot_dava_internal_SET_SETTryNode$object;

typedef const struct _jc_soot_dava_internal_SET_SETTryNode$vmethods	_jc_soot_dava_internal_SET_SETTryNode$vmethods;
typedef const struct _jc_soot_dava_internal_SET_SETTryNode$vtable	_jc_soot_dava_internal_SET_SETTryNode$vtable;
typedef const struct _jc_soot_dava_internal_SET_SETTryNode$vtype	_jc_soot_dava_internal_SET_SETTryNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_SET_SETTryNode$method$_init$a4d6c374d8192ed2(_jc_env *, struct _jc_soot_dava_internal_SET_SETTryNode$object *, struct _jc_soot_util_IterableSet$object *, struct _jc_soot_dava_toolkits_base_finders_ExceptionNode$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_DavaBody$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_dava_internal_AST_ASTNode$object *_jc_soot_dava_internal_SET_SETTryNode$method$emit__5fAST$9abd6bb299fe14c5(_jc_env *, struct _jc_soot_dava_internal_SET_SETTryNode$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_dava_internal_asg_AugmentedStmt$object *_jc_soot_dava_internal_SET_SETTryNode$method$get__5fEntryStmt$d3b7a698292e24c9(_jc_env *, struct _jc_soot_dava_internal_SET_SETTryNode$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_util_IterableSet$object *_jc_soot_dava_internal_SET_SETTryNode$method$get__5fNaturalExits$93615053d2db173e(_jc_env *, struct _jc_soot_dava_internal_SET_SETTryNode$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_dava_internal_SET_SETTryNode$method$resolve$e7ca43c456f15a88(_jc_env *, struct _jc_soot_dava_internal_SET_SETTryNode$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_SET_SETTryNode$method_info$emit__5fAST$9abd6bb299fe14c5;
extern _jc_method _jc_soot_dava_internal_SET_SETTryNode$method_info$get__5fEntryStmt$d3b7a698292e24c9;
extern _jc_method _jc_soot_dava_internal_SET_SETTryNode$method_info$get__5fNaturalExits$93615053d2db173e;
extern _jc_method _jc_soot_dava_internal_SET_SETTryNode$method_info$resolve$e7ca43c456f15a88;

// Virtual methods structure
struct _jc_soot_dava_internal_SET_SETTryNode$vmethods {
	struct _jc_soot_dava_internal_AST_ASTNode$object	*(*emit__5fAST$9abd6bb299fe14c5)(_jc_env *, struct _jc_soot_dava_internal_SET_SETTryNode$object *) _JC_JCNI_ATTR;
	struct _jc_soot_dava_internal_asg_AugmentedStmt$object	*(*get__5fEntryStmt$d3b7a698292e24c9)(_jc_env *, struct _jc_soot_dava_internal_SET_SETTryNode$object *) _JC_JCNI_ATTR;
	struct _jc_soot_util_IterableSet$object	*(*get__5fNaturalExits$93615053d2db173e)(_jc_env *, struct _jc_soot_dava_internal_SET_SETTryNode$object *) _JC_JCNI_ATTR;
	jboolean	(*resolve$e7ca43c456f15a88)(_jc_env *, struct _jc_soot_dava_internal_SET_SETTryNode$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_SET_SETTryNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_internal_SET_SETNode$vmethods	soot_dava_internal_SET_SETNode;
	_jc_soot_dava_internal_SET_SETTryNode$vmethods	soot_dava_internal_SET_SETTryNode;
};

// Vtype
struct _jc_soot_dava_internal_SET_SETTryNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_SET_SETTryNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETTryNode$sub_refs {
	struct _jc_soot_dava_toolkits_base_finders_ExceptionNode$object	*en;
	struct _jc_soot_dava_DavaBody$object	*davaBody;
	struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object	*asg;
	struct _jc_java_util_HashMap$object	*cb2clone;
	struct _jc_soot_dava_internal_asg_AugmentedStmt$object	*entgryStmt;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETTryNode$refs {
    _jc_soot_dava_internal_SET_SETTryNode$sub_refs	soot_dava_internal_SET_SETTryNode;
    _jc_soot_dava_internal_SET_SETNode$sub_refs	soot_dava_internal_SET_SETNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETTryNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETTryNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_internal_SET_SETNode$sub_nonrefs	soot_dava_internal_SET_SETNode;
    _jc_soot_dava_internal_SET_SETTryNode$sub_nonrefs	soot_dava_internal_SET_SETTryNode;
};

// Object instance structure
struct _jc_soot_dava_internal_SET_SETTryNode$object {
	_jc_soot_dava_internal_SET_SETTryNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_SET_SETTryNode$vtype	*vtype;
	_jc_soot_dava_internal_SET_SETTryNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_SET_SETTryNode$vtype _jc_soot_dava_internal_SET_SETTryNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_SET_SETTryNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_SET_SETTryNode$class_object;

#endif	/* _JC_soot_dava_internal_SET_SETTryNode_H_ */
